@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2014 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -38,19 +38,21 @@ EventDialog::EventDialog(int conferenceId, int eventId, QWidget *parent): QDialo
 
     QString info;
     // title
-    info.append(QString("<h1>%1</h1>\n").arg(event.title()));
+    info.append(QString("<h1>%1</h1>\n").arg(Qt::escape(event.title())));
 
     // persons
     info += QString("<h2>%1</h2>\n").arg(tr("Persons"));
-    info += QString("<p>%1</p>\n").arg(event.persons().join(", "));
+    QStringList persons = event.persons();
+    for (int i = 0; i != persons.size(); ++i) persons[i] = Qt::escape(persons[i]);
+    info += QString("<p>%1</p>\n").arg(persons.join(", "));
 
     // abstract
     info += QString("<h2>%1</h2>\n").arg(tr("Abstract"));
-    info += QString("<p>%1</p>\n").arg(event.abstract());
+    info += Qt::convertFromPlainText(event.abstract(), Qt::WhiteSpaceNormal);
 
     // description
     info += QString("<h2>%1</h2>\n").arg(tr("Description"));
-    info += QString("<p>%1</p>\n").arg(event.description());
+    info += Qt::convertFromPlainText(event.description(), Qt::WhiteSpaceNormal);
 
     // links
     info += QString("<h2>%1</h2>\n<ul>\n").arg(tr("Links"));
@@ -61,7 +63,7 @@ EventDialog::EventDialog(int conferenceId, int eventId, QWidget *parent): QDialo
         QString name(i.key());
         if (url.isEmpty() || url == "http://") continue;
         if (name.isEmpty()) name = url;
-        info += QString("<li><a href=\"%1\">%2</a></li>\n").arg(url, name);
+        info += QString("<li><a href=\"%1\">%2</a></li>\n").arg(Qt::escape(url), Qt::escape(name));
     }
     info += QString("</ul>\n");
     eventInfoTextBrowser->setHtml(info);
