@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2010 Ixonos Plc.
- * Copyright (C) 2011-2013 Philipp Spitzer, gregor herrmann, Stefan Stahl
+ * Copyright (C) 2011-2014 Philipp Spitzer, gregor herrmann, Stefan Stahl
  *
  * This file is part of ConfClerk.
  *
@@ -117,6 +117,9 @@ MainWindow::MainWindow(QWidget* parent): QMainWindow(parent) {
     addAction(settingsAction);
     addAction(quitAction);
 
+    // make it impossible to hide the toolbar by disallowing its context menu
+    toolBar->setContextMenuPolicy(Qt::PreventContextMenu);
+
     // open conference
     useConference(Conference::activeConference());
     // optimization, see useConference() code
